@@ -57,7 +57,7 @@ auto_test <- function(code_path, test_path, reporter = "summary",
       # If test changes, rerun just that test
       cat("Rerunning tests: ", paste0(basename(tests), collapse = ", "), "\n")
       with_reporter(reporter$copy(),
-        lapply(tests, .test_file, parent_env = env))
+        lapply(tests, test_file, env = env))
     }
 
     TRUE
@@ -108,7 +108,7 @@ auto_test_package <- function(pkg = ".", reporter = "summary") {
       # If test changes, rerun just that test
       cat("Rerunning tests: ", paste0(basename(tests), collapse = ", "), "\n")
       with_reporter(reporter$copy(),
-        lapply(tests, .test_file, parent_env = env))
+        lapply(tests, test_file, env = env))
     }
 
     TRUE
