@@ -12,11 +12,14 @@
 #' make_expectation(x)
 #'
 #' make_expectation(mtcars$mpg)
+#'
+#' df <- data.frame(x = 2)
+#' make_expectation(df)
 make_expectation <- function(x, expectation = "equals") {
   obj <- substitute(x)
   expectation <- match.arg(expectation,
     c("equals", "is_equivalent_to", "is_identical_to"))
-  
-  substitute(expect_that(obj, expectation(values)),
-    list(obj = obj, expectation = as.name(expectation), values = x))
-}
\ No newline at end of file
+
+  dput(substitute(expect_that(obj, expectation(values)),
+    list(obj = obj, expectation = as.name(expectation), values = x)))
+}
