@@ -50,25 +50,24 @@ SummaryReporter <- setRefClass("SummaryReporter", contains = "Reporter",
     },
 
     add_result = function(result) {
+      callSuper(result)
       has_tests <<- TRUE
       if (result$skipped) {
-        cat(colourise("S", fg = "yellow"))
+        cat(colourise("S", "skipped"))
         return()
       }
       if (result$passed) {
-        cat(colourise(".", fg = "light green"))
+        cat(colourise(".", "passed"))
         return()
       }
 
-      failed <<- TRUE
-
       if (n + 1 > length(labels) || n + 1 > max_reports) {
-        cat(colourise("F", fg = "red"))
+        cat(colourise("F", "error"))
       } else {
         n <<- n + 1L
         result$test <- if (is.null(test)) "(unknown)" else test
         failures[[n]] <<- result
-        cat(colourise(labels[n], fg = "red"))
+        cat(colourise(labels[n], "error"))
       }
     },
 
@@ -80,32 +79,16 @@ SummaryReporter <- setRefClass("SummaryReporter", contains = "Reporter",
       if (n == 0) {
         cat("\n")
         if (has_tests && sample(10, 1) == 1 && show_praise) {
-          cat(colourise(sample(.praise, 1), "light green"), "\n")
+          cat(colourise(sample(.praise, 1), "passed"), "\n")
+        } else {
+          cat(colourise("DONE", "passed"), "\n")
         }
       } else {
-        label <- labels[seq_len(n)]
-        type <- ifelse(sapply(failures, "[[", "error"), "Error", "Failure")
-        tests <- vapply(failures, "[[", "test", FUN.VALUE = character(1))
-
-        location <- vapply(failures, function(x) {
-          ref <- x$srcref
-          if ( is.null(ref) ) {
-            ''
-          } else {
-            paste0('(@', attr(ref, 'srcfile')$filename, '#', ref[1], ')')
-          }
-        }, '')
-        header <- paste0(label, ". ", type, location, ": ", tests, " ")
-
-        linewidth <- ifelse(nchar(header) > getOption("width"),0,getOption("width") - nchar(header))
-        line <- charrep("-", linewidth )
-
-        message <- vapply(failures, "[[", "failure_msg", FUN.VALUE = character(1))
-
-        reports <- paste0(
-          colourise(header, "red"), line, "\n",
-          message, "\n")
-        cat("\n", reports, sep = "\n")
+        cat("\n")
+        reports <- vapply(seq_len(n), function(i) {
+          failure_summary(failures[[i]], labels[i])
+        }, character(1))
+        cat(paste(reports, collapse = "\n\n"), "\n", sep = "")
       }
     }
   )
