@@ -4,24 +4,26 @@
 #' methods.
 #'
 #' @keywords internal.
-#' @aliases Reporter-class
-#' @exportClass Reporter
-Reporter <- setRefClass("Reporter", 
+#' @export
+#' @export Reporter
+#' @aliases Reporter
+#' @param ... Arguments used to initialise class
+#' @importFrom methods setRefClass
+Reporter <- setRefClass("Reporter",
   fields = list(
-    context = "character", 
-    test = "ANY", 
-    failed = "logical", 
+    context = "character",
+    test = "ANY",
+    failed = "logical",
     context_open = "logical"
   ), methods = list(
     initialize = function(...) {
       context_open <<- FALSE
       failed <<- FALSE
       test <<- NULL
-      
+
       initFields(...)
     },
     start_reporter = function() {
-      failed <<- FALSE
     },
     start_context = function(desc) {
       context <<- desc
@@ -29,7 +31,11 @@ Reporter <- setRefClass("Reporter",
     start_test = function(desc) {
       test <<- desc
     },
-    add_result = function(result) {},
+    add_result = function(result) {
+      if (!result$passed && !result$skipped) {
+        failed <<- TRUE
+      }
+    },
     end_test = function() {
       test <<- ""
     },
