@@ -26,11 +26,19 @@ is.skip <- function(x) inherits(x, "skip")
 #'
 #' This function allows you to skip a test if it's not currently available.
 #' This will produce an informative message, but will not cause the test
-#' suite to fail. \code{skip_on_cran()} uses \code{skip()}, together with
-#' the \code{NOT_CRAN} environment variable (set by devtools), to automatically
-#' skip tests that should not be run on CRAN.
+#' suite to fail.
 #'
-#' @param message An message describing why the test was skipped.
+#' @section Helpers:
+#' \code{skip_on_cran()} skips tests on CRAN, using the \code{NOT_CRAN}
+#' environment variable set by devtools.
+#'
+#' \code{skip_on_travis()} skips tests on travis by inspecting the
+#' \code{TRAVIS} environment variable.
+#'
+#' \code{skip_if_not_installed()} skips a tests if a package is not installed
+#' (useful for suggested packages).
+#'
+#' @param message A message describing why the test was skipped.
 #' @export
 #' @examples
 #' if (FALSE) skip("No internet connection")
@@ -39,6 +47,15 @@ skip <- function(message) {
   stop(cond)
 }
 
+#' @export
+#' @param pkg Name of package to check for
+#' @rdname skip
+skip_if_not_installed <- function(pkg) {
+  if (requireNamespace(pkg, quietly = TRUE)) return()
+
+  skip(paste0(pkg, " not installed"))
+}
+
 #' @export
 #' @rdname skip
 skip_on_cran <- function() {
@@ -46,3 +63,11 @@ skip_on_cran <- function() {
 
   skip("On CRAN")
 }
+
+#' @export
+#' @rdname skip
+skip_on_travis <- function() {
+  if (!identical(Sys.getenv("TRAVIS"), "true")) return()
+
+  skip("On Travis")
+}
